pub enum InsertErrorVal<T> {
    InvalidIndex(T),
    InsufficientCapacity(T),
}
This is supported on crate feature arrayvec only.
An error returned from try_insert_val method.

Variants

InvalidIndex(T)

Requested index is out of bounds

InsufficientCapacity(T)

There is no spare capacity to accommodate a new element.

Implementations

Returns a reference to the value conveyed by the error.

Returns the value conveyed by the error.